summaryrefslogtreecommitdiff
path: root/src/querystring_gui.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/querystring_gui.h')
-rw-r--r--src/querystring_gui.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/querystring_gui.h b/src/querystring_gui.h
index a1f3896dd..f67809b78 100644
--- a/src/querystring_gui.h
+++ b/src/querystring_gui.h
@@ -37,7 +37,7 @@ struct QueryString {
* @param size Maximum size in bytes.
* @param chars Maximum size in chars.
*/
- QueryString(uint16 size, uint16 chars = UINT16_MAX) : ok_button(ACTION_NOTHING), cancel_button(ACTION_DESELECT), text(size, chars), orig(NULL)
+ QueryString(uint16 size, uint16 chars = UINT16_MAX) : ok_button(ACTION_NOTHING), cancel_button(ACTION_DESELECT), text(size, chars), orig(nullptr)
{
}
@@ -79,11 +79,11 @@ public:
/**
* Get the currently marked text.
* @param[out] length Length of the marked text.
* @return Begining of the marked area or NULL if no text is marked.
*/
const char *GetMarkedText(size_t *length) const
{
- if (this->text.markend == 0) return NULL;
+ if (this->text.markend == 0) return nullptr;
*length = this->text.markend - this->text.markpos;
return this->text.buf + this->text.markpos;
@@ -79,11 +79,11 @@ public:
* Get the currently marked text.
* @param[out] length Length of the marked text.
- * @return Begining of the marked area or NULL if no text is marked.
+ * @return Begining of the marked area or nullptr if no text is marked.
*/
const char *GetMarkedText(size_t *length) const